@@ -16,25 +16,8 @@ sub isEnabled {
     return 1;
 }
 
-sub _encapsulate {
-   my ( $self, $msg ) = @_;
-
-   $self->{logger}->info("Task Encapsulation...");
-
-   my $header = '{ "agentVersion": "'.$FusionInventory::Agent::VERSION.'",
-		   "deviceid": "'.$self->{agentid}.'",
-                   "task":';
-   my $footer = '}';
-
-   $msg = $header.$msg.$footer;
-
-   return $msg;
-}
-
 sub run {
     my ( $self, %params ) = @_;
-
-    $self->{logger}->info("Running Armadito module, plugin_server_url= ".$self->{config}->{plugin_server_url});
  
     $self->{client} = Armadito::Agent::HTTP::Client::Armadito->new();
     die "Error when creating client!" unless $self->{client};
@@ -47,8 +30,20 @@ sub new {
 
     my $self = { config => $params{config}};
 
-    $self->{logger} = FusionInventory::Agent::Logger->new(backends => ['Syslog', 'Stderr']);
-    $self->{agentid} = 0;
+	$self->{agent} = $params{agent};
+	$self->{logger} = $self->{agent}->{logger};
+
+	$self->{jobj} = {
+		agent_id => $self->{agent}->{agent_id},
+		agent_version => $FusionInventory::Agent::VERSION,
+		task => ""
+	};
+
+	if(defined($self->{agent}->{fusionid})){
+		$self->{logger}->info("Fusion Device Id : ".$self->{agent}->{fusionid});
+	}
+
+	$self->{logger}->info("Armadito agent Id : ".$self->{agent}->{agent_id});
 
     bless $self, $class;
     return $self;
