@@ -24,53 +24,35 @@ sub new {
         $self->{debug} = 1;
     }
 
+	my $task = {
+		name => "State",
+		antivirus => ""
+	};	
+
+	$self->{jobj}->{task} = $task;
+
     return $self;
 }
 
-sub _encapsulate {
-
-   my ( $self, $msg ) = @_;
-
-   $self->{logger}->info("State Task Encapsulation...");
-
-   # add State Task info here
-   $msg = '{ "taskname": "State", "msg": '.$msg."}"; 
-
-   $msg = $self->SUPER::_encapsulate($msg);
-
-   return $msg;
-}
-
 sub _handleResponse {
-
     my ($self, $response) = @_;
 
-    # Parse response
-    # print Dumper($response);
-    print "Successful Response : ".$response->content()."\n";
-
+    $self->{logger}->info("Successful Response : ".$response->content());
     my $obj =  from_json($response->content(), { utf8  => 1 });
-
-    print Dumper($obj);
+    $self->{logger}->info(Dumper($obj));
 
     return $self;
 }
 
 sub _handleError {
-
     my ($self, $response) = @_;
 
-    # Parse response
-    # print Dumper($response);
-    print "Error Response : ".$response->content()."\n";
-
+    $self->{logger}->info("Error Response : ".$response->content());
     my $obj =  from_json($response->content(), { utf8  => 1 });
-
-    print Dumper($obj);
+    $self->{logger}->error(Dumper($obj));
 
     return $self;
 }
-
 sub run {
     my ( $self, %params ) = @_;
 
